CallbackTypeCustom class final

Uses a custom scheme for the redirect URI.

Platform support: iOS, macOS, Android

Inheritance

Constructors

CallbackTypeCustom(String scheme, {String host = '*', String path = '/*'})
Uses a custom scheme for the redirect URI.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
The host to listen on for redirects.
final
path → String
The path to listen on for redirects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The custom scheme to use for the redirect URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited