CallbackTypeHttps class final

Uses an HTTPS scheme for the redirect URI.

The HTTPS scheme must point to a host that you own and is registered to your application via the respective platform mechanisms.

Platform support: Android, iOS (17.4+), macOS (14.4+), Web

Inheritance

Constructors

CallbackTypeHttps({required String host, required String path})
Uses an HTTPS scheme for the redirect URI.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
The host (domain) to use for the redirect URI, e.g. example.com.
final
path → String
The path to use for the redirect URI, e.g. /auth.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited